@@ -229,6 +229,8 @@ destroy_pager(GtkWidget * widget, PagerData *pager)
 	pager->listeners[1] = 0;
 	pager->listeners[2] = 0;
 
+	/* FIXME: does this not leak PagerData ? */
+
 }
 
 static const BonoboUIVerb pager_menu_verbs [] = {
@@ -373,7 +375,7 @@ fill_pager_applet(PanelApplet *applet)
 	error = NULL;
 	pager->n_rows = panel_applet_gconf_get_int (applet, "num_rows", &error);
 	if (error) {
-                g_printerr (_("Error loading num_rows value for workspace switcher applet: %s\n"),
+                g_printerr (_("Error loading num_rows value for Workspace Switcher: %s\n"),
                             error->message);
 		g_error_free (error);
                 /* leave current value */
@@ -384,7 +386,7 @@ fill_pager_applet(PanelApplet *applet)
 	error = NULL;
 	display_names = panel_applet_gconf_get_bool (applet, "display_workspace_names", &error);
 	if (error) {
-                g_printerr (_("Error loading display_workspace_names value for workspace switcher applet: %s\n"),
+                g_printerr (_("Error loading display_workspace_names value for Workspace Switcher: %s\n"),
                             error->message);
 		g_error_free (error);
                 /* leave current value */
@@ -399,7 +401,7 @@ fill_pager_applet(PanelApplet *applet)
 	error = NULL;
 	pager->display_all = panel_applet_gconf_get_bool (applet, "display_all_workspaces", &error);
 	if (error) {
-                g_printerr (_("Error loading display_all_workspaces value for workspace switcher applet: %s\n"),
+                g_printerr (_("Error loading display_all_workspaces value for Workspace Switcher: %s\n"),
                             error->message);
 		g_error_free (error);
                 /* leave current value */
@@ -542,8 +544,8 @@ display_about_dialog (BonoboUIComponent *uic,
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free(file);
 
-	about = gnome_about_new (_("Workspace Switcher"), "1.0",
-				 _("(c) 2001 Red Hat, Inc."),
+	about = gnome_about_new (_("Workspace Switcher"), VERSION,
+				 "Copyright \xc2\xa9 2001-2002 Red Hat, Inc.",
 				 _("The Workspace Switcher shows you a small version of your workspaces that lets you manage your windows."),
 				 authors,
 				 documenters,
