@@ -398,10 +398,10 @@ display_help_dialog (BonoboUIComponent *uic,
                                                      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
         }
 
-        egg_screen_help_display_desktop (
+        egg_help_display_desktop_on_screen (
+                applet_program, "show-desktop", "show-desktop", NULL,
                 gtk_widget_get_screen (sdd->applet),
-                applet_program, "show-desktop", "show-desktop",
-                NULL, &error);
+		&error);
 
         if (error) {
                 GtkWidget *dialog;
@@ -450,7 +450,7 @@ display_about_dialog (BonoboUIComponent *uic,
         }
 
         about = gnome_about_new (_("Show Desktop Button"), VERSION,
-                                 _("(C) 2002 Red Hat, Inc."),
+                                 "Copyright \xc2\xa9 2002 Red Hat, Inc.",
                                  _("This button lets you hide all windows and show the desktop"),
                                  authors,
                                  documenters,
