@@ -45,7 +45,6 @@ static GConfEnumStringPair object_type_enum_map [] = {
 	{ APPLET_DRAWER,   "drawer-object" },
 	{ APPLET_MENU,     "menu-object" },
 	{ APPLET_LAUNCHER, "launcher-object" }, 
-	{ APPLET_EMPTY,    "empty-object" },
 	{ APPLET_BONOBO,   "bonobo-applet" },
 	{ APPLET_ACTION,   "action-applet" },
 	{ APPLET_LOCK,     "lock-object" },   /* FIXME:                           */
@@ -221,6 +220,8 @@ applet_callback_callback (GtkWidget      *widget,
 			panel_show_help (screen, "wgospanel.xml", "gospanel-37");
 		break;
 	case APPLET_ACTION:
+	case APPLET_LOGOUT:
+	case APPLET_LOCK:
 		panel_action_button_invoke_menu (
 			PANEL_ACTION_BUTTON (menu->info->widget), menu->name);
 		break;
@@ -341,24 +342,22 @@ panel_applet_remove_callback (AppletInfo *info,
 }
 
 static void
-setup_an_item(AppletUserMenu *menu,
-	      GtkWidget *submenu,
-	      int is_submenu)
+setup_an_item (AppletUserMenu *menu,
+	       GtkWidget      *submenu,
+	       int             is_submenu)
 {
+	GtkWidget *image = NULL;
+
 	menu->menuitem = gtk_image_menu_item_new ();
 
 	g_signal_connect (G_OBJECT (menu->menuitem), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &menu->menuitem);
-	if(menu->stock_item && *(menu->stock_item))
-		setup_menuitem (menu->menuitem,
-				gtk_image_new_from_stock (menu->stock_item,
-							  GTK_ICON_SIZE_MENU),
-				menu->text);
-	else
-		setup_menuitem (menu->menuitem,
-				NULL,
-				menu->text);
+
+	if (menu->stock_item && menu->stock_item [0])
+		image = gtk_image_new_from_stock (menu->stock_item, GTK_ICON_SIZE_MENU);
+
+	setup_menuitem (menu->menuitem, GTK_ICON_SIZE_MENU, image, menu->text);
 
 	if(submenu)
 		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menu->menuitem);
@@ -490,7 +489,7 @@ panel_applet_create_menu (AppletInfo *info)
 		image = gtk_image_new_from_stock (GTK_STOCK_REMOVE,
 						  GTK_ICON_SIZE_MENU);
 
-		setup_menuitem (menuitem, image , _("_Remove From Panel"));
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image , _("_Remove From Panel"));
 
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (applet_remove_callback), info);
@@ -502,7 +501,7 @@ panel_applet_create_menu (AppletInfo *info)
 		/* FIXME: should have a "Move" pixmap.
 		 */
 		image = gtk_image_new ();
-		setup_menuitem (menuitem, image, _("_Move"));
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, image, _("_Move"));
 
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (move_applet_callback), info);
@@ -674,22 +673,6 @@ panel_applet_destroy (GtkWidget  *widget,
 	g_free (info);
 }
 
-static G_CONST_RETURN char *
-panel_applet_get_full_gconf_key (AppletType   type,
-				 const gchar *profile,
-				 const gchar *object_id,
-				 const gchar *key)
-{
-	PanelGConfKeyType  gconf_type;
-
-	if (type == APPLET_BONOBO)
-		gconf_type = PANEL_GCONF_APPLETS;
-	else
-		gconf_type = PANEL_GCONF_OBJECTS;
-
-	return panel_gconf_full_key (gconf_type, profile, object_id, key);
-}
-
 typedef struct {
 	AppletType   type;
 	PanelWidget *panel_widget;
@@ -753,11 +736,13 @@ panel_applet_load_idle_handler (gpointer dummy)
 	case APPLET_LOGOUT:  /* FIXME: This is backward compatibility only. */
 	case APPLET_LOCK:    /*        Remove at some time in the future    */
 		panel_action_button_load (
-				APPLET_LOGOUT ? PANEL_ACTION_LOGOUT : PANEL_ACTION_LOCK,
+				applet->type == APPLET_LOGOUT ? PANEL_ACTION_LOGOUT :
+								PANEL_ACTION_LOCK,
 				applet->panel_widget,
 				applet->position,
 				TRUE,
-				applet->unique_id);
+				applet->unique_id,
+				TRUE);
 		break;
 	case APPLET_ACTION:
 		panel_action_button_load_from_gconf (
@@ -788,10 +773,10 @@ panel_destroyed_while_loading (GtkWidget *panel, gpointer data)
 }
 
 static void
-panel_applet_load_from_unique_id (AppletType   type,
-				  GConfClient *gconf_client,
-				  const char  *profile,
-				  const char  *unique_id)
+panel_applet_load_from_unique_id (PanelGConfKeyType  type,
+				  GConfClient       *gconf_client,
+				  const char        *profile,
+				  const char        *unique_id)
 {
 	PanelAppletToLoad *applet;
 	PanelWidget       *panel_widget;
@@ -802,8 +787,7 @@ panel_applet_load_from_unique_id (AppletType   type,
 	int                position;
 	gboolean           right_stick;
 
-	temp_key = panel_applet_get_full_gconf_key (
-			type, profile, unique_id, "object_type");
+	temp_key = panel_gconf_full_key (type, profile, unique_id, "object_type");
 	type_string = gconf_client_get_string (gconf_client, temp_key, NULL);
 	if (!type_string) {
 		g_printerr (_("No object_type set for panel object with ID %s\n"), unique_id);
@@ -820,20 +804,17 @@ panel_applet_load_from_unique_id (AppletType   type,
 	
 	g_free (type_string);
 
-	temp_key = panel_applet_get_full_gconf_key (
-			type, profile, unique_id, "position");
+	temp_key = panel_gconf_full_key (type, profile, unique_id, "position");
 	position = gconf_client_get_int (gconf_client, temp_key, NULL);
 	
-	temp_key = panel_applet_get_full_gconf_key (
-			type, profile, unique_id, "panel_id");
+	temp_key = panel_gconf_full_key (type, profile, unique_id, "panel_id");
 	panel_id = gconf_client_get_string (gconf_client, temp_key, NULL);
 	if (!panel_id) {
 		g_printerr (_("No panel_id set for panel object with ID %s\n"), unique_id);
 		return;
 	}
-        
-	temp_key = panel_applet_get_full_gconf_key (
-			type, profile, unique_id, "panel_right_stick");
+
+	temp_key = panel_gconf_full_key (type, profile, unique_id, "panel_right_stick");
 	right_stick = gconf_client_get_bool (gconf_client, temp_key, NULL);
 
 	panel_widget = panel_widget_get_by_id (panel_id);
@@ -860,7 +841,7 @@ panel_applet_load_from_unique_id (AppletType   type,
 }
 
 static void
-panel_applet_load_list (AppletType type)
+panel_applet_load_list (PanelGConfKeyType type)
 {
 	GConfClient *client;
 	GSList      *id_list, *l;
@@ -870,7 +851,7 @@ panel_applet_load_list (AppletType type)
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
-	if (type == APPLET_BONOBO)
+	if (type == PANEL_GCONF_APPLETS)
 		temp_key = panel_gconf_general_key (profile, "applet_id_list");
 	else
         	temp_key = panel_gconf_general_key (profile, "object_id_list");
@@ -898,8 +879,8 @@ panel_applet_compare (const PanelAppletToLoad *a,
 void
 panel_applet_load_applets_from_gconf (void)
 {
-	panel_applet_load_list (APPLET_BONOBO);
-	panel_applet_load_list (APPLET_EMPTY);
+	panel_applet_load_list (PANEL_GCONF_APPLETS);
+	panel_applet_load_list (PANEL_GCONF_OBJECTS);
 
 	if (!panel_applets_to_load)
 		return;
@@ -910,6 +891,117 @@ panel_applet_load_applets_from_gconf (void)
 	g_idle_add (panel_applet_load_idle_handler, NULL);
 }
 
+static void
+panel_applet_load_default_applet_for_screen (PanelGConfKeyType  type,
+					     const char        *profile,
+					     const char        *applet_id,
+					     int                screen)
+{
+	GConfClient *client;
+	GError      *error = NULL;
+	GSList      *id_list, *l;
+	const char  *key;
+	char        *new_applet_id;
+	char        *panel_id, *new_panel_id;
+
+	new_applet_id = panel_gconf_load_default_config_for_screen (
+				type, profile, applet_id, screen, &error);
+	if (error) {
+		g_warning ("Could not load default config for applet '%s': '%s'\n",
+			   applet_id, error->message);
+		g_error_free (error);
+		return;
+	}
+
+	client = panel_gconf_get_client ();
+
+	key = panel_gconf_full_key (type, profile, new_applet_id, "panel_id");
+	panel_id = gconf_client_get_string (client, key, NULL);
+	if (!panel_id) {
+		g_printerr (_("No panel_id set for panel object with ID %s\n"), new_applet_id);
+		g_free (new_applet_id);
+		return;
+	}
+
+	new_panel_id = g_strdup_printf ("%s_screen%d", panel_id, screen);
+	gconf_client_set_string (client, key, new_panel_id, NULL);
+	g_free (new_panel_id);
+	g_free (panel_id);
+
+	if (type == PANEL_GCONF_APPLETS)
+		key = panel_gconf_general_key (profile, "applet_id_list");
+	else
+		key = panel_gconf_general_key (profile, "object_id_list");
+
+	id_list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
+
+	for (l = id_list; l; l = l->next)
+		if (!strcmp (new_applet_id, (char *) l->data))
+			break;
+
+	if (!l) {
+		id_list = g_slist_prepend (id_list, new_applet_id);
+		new_applet_id = NULL;
+
+		gconf_client_set_list (client, key, GCONF_VALUE_STRING, id_list, NULL);
+	}
+
+	panel_g_slist_deep_free (id_list);
+	g_free (new_applet_id);
+}
+
+void
+panel_applet_load_defaults_for_screen (PanelGConfKeyType  type,
+				       const char        *profile,
+				       int                screen)
+{
+	GConfClient *client;
+	GSList      *applets, *l;
+	GError      *error = NULL;
+	const char  *subdir = NULL;
+	const char  *schemas_dir = NULL;
+
+	switch (type) {
+	case PANEL_GCONF_APPLETS:
+		subdir = "applets";
+		break;
+	case PANEL_GCONF_OBJECTS:
+		subdir = "objects";
+		break;
+	default:
+		g_assert_not_reached ();
+		break;
+	}
+
+	client = panel_gconf_get_client ();
+
+	/* FIXME: "medium" shouldn't be hardcoded.
+	 */
+	schemas_dir = panel_gconf_sprintf (
+			"/schemas/apps/panel/default_profiles/medium/%s", subdir);
+
+	applets = gconf_client_all_dirs (client, schemas_dir, &error);
+	if (error) {
+		g_warning ("Cannot list default '%s': '%s'\n", subdir, error->message);
+		g_error_free (error);
+		return;
+	}
+
+	for (l = applets; l; l = l->next) {
+		char *applet_id;
+
+		applet_id = g_path_get_basename (l->data);
+
+		panel_applet_load_default_applet_for_screen (	
+				type, profile, applet_id, screen);
+
+		g_free (applet_id);
+		g_free (l->data);
+	}
+
+        g_slist_free (applets);
+}
+
 static G_CONST_RETURN char *
 panel_applet_get_panel_id (AppletInfo *applet)
 {
@@ -949,12 +1041,13 @@ panel_applet_save_position (AppletInfo *applet_info,
 			    const char *gconf_key,
 			    gboolean    immediate)
 {
-	GConfClient  *client;
-	const char   *profile;
-	const char   *temp_key;
-	const char   *panel_id;
-	gboolean      right_stick;
-	int           position;
+	PanelGConfKeyType  key_type;
+	GConfClient       *client;
+	const char        *profile;
+	const char        *temp_key;
+	const char        *panel_id;
+	gboolean           right_stick;
+	int                position;
 
 	g_return_if_fail (applet_info != NULL);
 
@@ -978,31 +1071,36 @@ panel_applet_save_position (AppletInfo *applet_info,
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
 
-	temp_key = panel_applet_get_full_gconf_key (
-			applet_info->type, profile, gconf_key, "panel_id");
+	if (applet_info->type == APPLET_BONOBO)
+		key_type = PANEL_GCONF_APPLETS;
+	else
+		key_type = PANEL_GCONF_OBJECTS;
+
+	temp_key = panel_gconf_full_key (key_type, profile, gconf_key, "panel_id");
 	gconf_client_set_string (client, temp_key, panel_id, NULL);
 
 	right_stick = panel_is_applet_right_stick (applet_info->widget);
-	temp_key = panel_applet_get_full_gconf_key (
-			applet_info->type, profile, gconf_key, "panel_right_stick");
+	temp_key = panel_gconf_full_key (
+			key_type, profile, gconf_key, "panel_right_stick");
 	gconf_client_set_bool (client, temp_key, right_stick, NULL);
 
 	position = panel_applet_get_position (applet_info);
 	if (right_stick && !PANEL_WIDGET (applet_info->widget->parent)->packed)
 		position = PANEL_WIDGET (applet_info->widget->parent)->size - position;
 
-	temp_key = panel_applet_get_full_gconf_key (
-			applet_info->type, profile, gconf_key, "position");
+	temp_key = panel_gconf_full_key (
+			key_type, profile, gconf_key, "position");
 	gconf_client_set_int (client, temp_key, position, NULL);
 }
 
 void
 panel_applet_save_to_gconf (AppletInfo *applet_info)
 {
-	GConfClient *client;
-	const char  *profile;
-	const char  *temp_key;
-	GSList      *id_list, *l;
+	PanelGConfKeyType  key_type;
+	GConfClient       *client;
+	const char        *profile;
+	const char        *temp_key;
+	GSList            *id_list, *l;
 
 	client  = panel_gconf_get_client ();
 	profile = panel_gconf_get_profile ();
@@ -1029,12 +1127,17 @@ panel_applet_save_to_gconf (AppletInfo *applet_info)
 
 	panel_g_slist_deep_free (id_list);
 
-	temp_key = panel_applet_get_full_gconf_key (applet_info->type, profile,
-						    applet_info->gconf_key,
-						    "object_type");
-	gconf_client_set_string (client, temp_key,
-				 gconf_enum_to_string (object_type_enum_map, applet_info->type),
-				 NULL);
+	if (applet_info->type == APPLET_BONOBO)
+		key_type = PANEL_GCONF_APPLETS;
+	else
+		key_type = PANEL_GCONF_OBJECTS;
+
+	temp_key = panel_gconf_full_key (
+			key_type, profile, applet_info->gconf_key, "object_type");
+	gconf_client_set_string (
+		client, temp_key,
+		gconf_enum_to_string (object_type_enum_map, applet_info->type),
+		NULL);
 
 	panel_applet_save_position (applet_info, applet_info->gconf_key, TRUE);
 
@@ -1056,14 +1159,12 @@ panel_applet_save_to_gconf (AppletInfo *applet_info)
 					applet_info->gconf_key);
 		break;
 	case APPLET_ACTION:
+	case APPLET_LOGOUT:
+	case APPLET_LOCK:
 		panel_action_button_save_to_gconf (
 			PANEL_ACTION_BUTTON (applet_info->widget),
 			applet_info->gconf_key);
 		break;
-	case APPLET_LOGOUT:
-	case APPLET_LOCK:
-		g_assert_not_reached ();
-		break;
 	default:
 		break;
 	}
