@@ -174,7 +174,7 @@ struct _BasePPosClass {
 GType           basep_pos_get_type              (void) G_GNUC_CONST;
 GType		basep_widget_get_type		(void) G_GNUC_CONST;
 
-GtkWidget*	basep_widget_construct		(gchar *panel_id,
+GtkWidget*	basep_widget_construct		(const char *panel_id,
 						 BasePWidget *basep,
 						 gboolean packed,
 						 gboolean reverse_arrows,
@@ -187,7 +187,7 @@ GtkWidget*	basep_widget_construct		(gchar *panel_id,
 						 gboolean hidebuttons_enabled,
 						 gboolean hidebutton_pixmaps_enabled,
 						 PanelBackgroundType back_type,
-						 char *back_pixmap,
+						 const char *back_pixmap,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
@@ -204,7 +204,7 @@ void		basep_widget_change_params	(BasePWidget *basep,
 						 gboolean hidebuttons_enabled,
 						 gboolean hidebutton_pixmaps_enabled,
 						 PanelBackgroundType back_type,
-						 char *pixmap_name,
+						 const char *pixmap_name,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
