@@ -5,16 +5,12 @@
 
 G_BEGIN_DECLS
 
-void       applet_menu_position   (GtkMenu  *menu,
-				   gint     *x,
-				   gint     *y,
-				   gboolean *push_in,
-				   gpointer  data);
-void       applet_menu_position_outside   (GtkMenu  *menu,
-					   gint     *x,
-					   gint     *y,
-					   gboolean *push_in,
-					   gpointer  data);
+void panel_position_applet_menu (GtkMenu   *menu,
+				 int       *x, 
+				 int       *y,
+				 gboolean  *push_in,
+				 GtkWidget *widget);
+
 
 void       panel_menu_position    (GtkMenu  *menu,
 				   gint     *x,
@@ -35,9 +31,9 @@ char *     get_pixmap              (const char *menudir,
 
 GtkWidget *add_menu_separator     (GtkWidget *menu);
 
-GtkWidget * pixmap_menu_item_new (const char *text, const char *try_file, gboolean force_image);
-void menu_util_screenshot (GtkWidget *widget, gpointer data);
-void menu_util_search (GtkWidget *widget, gpointer data);
+GtkWidget *stock_menu_item_new (const char *text,
+				const char *stock_id,
+				gboolean    force_image);
 
 int        get_default_menu_flags (void);
 gboolean   got_kde_menus (void);
