@@ -1,35 +1,17 @@
-#ifndef XSTUFF_H
+#ifndef __XSTUFF_H__
+#define __XSTUFF_H__
 
-#include <gdk/gdkx.h>
-
-#include <X11/Xmd.h>
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
+#include <gdk/gdk.h>
+#include <gtk/gtkwidget.h>
 
 void xstuff_init			(void);
-Atom xstuff_atom_intern			(Display *display,
-					 const char *name);
-void xstuff_set_simple_hint		(GdkWindow *w,
-					 const char *name,
-					 long val);
 void xstuff_delete_property		(GdkWindow *window,
 					 const char *name);
 gboolean xstuff_is_compliant_wm		(void);
-
-gpointer get_typed_property_data	(Display *xdisplay,
-					 Window   xwindow,
-					 Atom     property,
-					 Atom     requested_type,
-					 gint    *size_p,
-					 guint    expected_format);
+gboolean xstuff_net_wm_supports         (const char *hint);
 
 void xstuff_set_no_group_and_no_input	(GdkWindow *win);
 
-void xstuff_setup_desktop_area		(int screen,
-					 int left,
-					 int right,
-					 int top,
-					 int bottom);
 void xstuff_unsetup_desktop_area	(void);
 void xstuff_set_pos_size		(GdkWindow *window,
 					 int x, int y,
@@ -42,4 +24,7 @@ void xstuff_set_wmspec_strut		(GdkWindow *window,
 					 int top,
 					 int bottom);
 
-#endif
+void xstuff_zoom_animate                (GtkWidget    *widget,
+					 GdkRectangle *opt_src_rect);
+
+#endif /* __XSTUFF_H__ */
